| Title: | Generalized Farlie-Gumbel-Morgenstern Copula |
|---|---|
| Description: | Compute bivariate dependence measures and perform bivariate competing risks analysis under the generalized Farlie-Gumbel-Morgenstern (FGM) copula. See Shih and Emura (2018) <doi:10.1007/s00180-018-0804-0> and Shih and Emura (2019) <doi:10.1007/s00362-016-0865-5> for details. |
| Authors: | Jia-Han Shih |
| Maintainer: | Jia-Han Shih <[email protected]> |
| License: | GPL-2 |
| Version: | 1.0.4 |
| Built: | 2026-05-21 06:51:52 UTC |
| Source: | https://github.com/cran/GFGM.copula |
Compute bivariate dependence measures and perform bivariate competing risks analysis under the generalized Farlie-Gumbel-Morgenstern (FGM) copula. See Shih and Emura (2016, 2018) for details.
The functions in this package are based on latent failure time models with competing risks in Shih and Emura (2018). However, they can be adapted to dependent censoring models in Emura and Chen (2018). See MLE.GFGM.spline for example.
Jia-Han Shih
Maintainer: Jia-Han Shih <[email protected]>
Shih J-H, Emura T (2016) Bivariate dependence measures and bivariate competing risks models under the generalized FGM copula, Statistical Papers, doi: 10.1007/s00362-016-0865-5.
Shih J-H, Emura T (2018) Likelihood-based inference for bivariate latent failure time models with competing risks udner the generalized FGM copula, Computational Statistics, doi: 10.1007/s00180-018-0804-0.
Emura T, Chen Y-H (2018) Analysis of Survival Data with Dependent Censoring, Copula-Based Approaches, JSS Research Series in Statistics, Springer, in press.
Compute the Cramer-von Mises type statistics under the generalized FGM copula.
CvM.GFGM.BurrIII( t.event, event1, event2, Alpha, Beta, Gamma, g1, g2, p, q, theta, eta = 0, Sdist.plot = TRUE )CvM.GFGM.BurrIII( t.event, event1, event2, Alpha, Beta, Gamma, g1, g2, p, q, theta, eta = 0, Sdist.plot = TRUE )
t.event |
Vector of the observed failure times. |
event1 |
Vector of the indicators for the failure cause 1. |
event2 |
Vector of the indicators for the failure cause 2. |
Alpha |
Positive shape parameter for the Burr III margin (failure cause 1). |
Beta |
Positive shape parameter for the Burr III margin (failure cause 2). |
Gamma |
Common positive shape parameter for the Burr III margins. |
g1 |
Splines coefficients for the failure cause 1. |
g2 |
Splines coefficients for the failure cause 2. |
p |
Copula parameter that greater than or equal to 1. |
q |
Copula parameter that greater than 1 (integer). |
theta |
Copula parameter with restricted range. |
eta |
Location parameter with default value 0. |
Sdist.plot |
Plot sub-distribution functions if |
The copula parameter q is restricted to be a integer due to the binominal theorem.
The admissible range of theta is given in Dependence.GFGM.
S.overall |
Cramer-von Mises type statistic based on parametric and non-parametric estimators of sub-distribution functions for testing overall model. |
S.GFGM |
Cramer-von Mises type statistic based on semi-parametric and non-parametric estimators of sub-distribution functions for testing the generalized FGM copula. |
Shih J-H, Emura T (2018) Likelihood-based inference for bivariate latent failure time models with competing risks udner the generalized FGM copula, Computational Statistics, 33:1293-1323.
Dependence.GFGM, MLE.GFGM.BurrIII, MLE.GFGM.spline
con = c(16,224,16,80,128,168,144,176,176,568,392,576,128,56,112,160,384,600,40,416, 408,384,256,246,184,440,64,104,168,408,304,16,72,8,88,160,48,168,80,512, 208,194,136,224,32,504,40,120,320,48,256,216,168,184,144,224,488,304,40,160, 488,120,208,32,112,288,336,256,40,296,60,208,440,104,528,384,264,360,80,96, 360,232,40,112,120,32,56,280,104,168,56,72,64,40,480,152,48,56,328,192, 168,168,114,280,128,416,392,160,144,208,96,536,400,80,40,112,160,104,224,336, 616,224,40,32,192,126,392,288,248,120,328,464,448,616,168,112,448,296,328,56, 80,72,56,608,144,408,16,560,144,612,80,16,424,264,256,528,56,256,112,544, 552,72,184,240,128,40,600,96,24,184,272,152,328,480,96,296,592,400,8,280, 72,168,40,152,488,480,40,576,392,552,112,288,168,352,160,272,320,80,296,248, 184,264,96,224,592,176,256,344,360,184,152,208,160,176,72,584,144,176) uncon = c(368,136,512,136,472,96,144,112,104,104,344,246,72,80,312,24,128,304,16,320, 560,168,120,616,24,176,16,24,32,232,32,112,56,184,40,256,160,456,48,24, 200,72,168,288,112,80,584,368,272,208,144,208,114,480,114,392,120,48,104,272, 64,112,96,64,360,136,168,176,256,112,104,272,320,8,440,224,280,8,56,216, 120,256,104,104,8,304,240,88,248,472,304,88,200,392,168,72,40,88,176,216, 152,184,400,424,88,152,184) cen = rep(630,44) t.event = c(con,uncon,cen) event1 = c(rep(1,length(con)),rep(0,length(uncon)),rep(0,length(cen))) event2 = c(rep(0,length(con)),rep(1,length(uncon)),rep(0,length(cen))) library(GFGM.copula) #res.BurrIII = MLE.GFGM.BurrIII(t.event,event1,event2,5000,3,2,0.75,eta = -71) #Alpha = res.BurrIII$Alpha[1] #Beta = res.BurrIII$Beta[1] #Gamma = res.BurrIII$Gamma[1] #res.spline = MLE.GFGM.spline(t.event,event1,event2,3,2,0.75) #g1 = res.spline$g1 #g2 = res.spline$g2 #CvM.GFGM.BurrIII(t.event,event1,event2,Alpha,Beta,Gamma,g1,g2,3,2,0.75,eta = -71)con = c(16,224,16,80,128,168,144,176,176,568,392,576,128,56,112,160,384,600,40,416, 408,384,256,246,184,440,64,104,168,408,304,16,72,8,88,160,48,168,80,512, 208,194,136,224,32,504,40,120,320,48,256,216,168,184,144,224,488,304,40,160, 488,120,208,32,112,288,336,256,40,296,60,208,440,104,528,384,264,360,80,96, 360,232,40,112,120,32,56,280,104,168,56,72,64,40,480,152,48,56,328,192, 168,168,114,280,128,416,392,160,144,208,96,536,400,80,40,112,160,104,224,336, 616,224,40,32,192,126,392,288,248,120,328,464,448,616,168,112,448,296,328,56, 80,72,56,608,144,408,16,560,144,612,80,16,424,264,256,528,56,256,112,544, 552,72,184,240,128,40,600,96,24,184,272,152,328,480,96,296,592,400,8,280, 72,168,40,152,488,480,40,576,392,552,112,288,168,352,160,272,320,80,296,248, 184,264,96,224,592,176,256,344,360,184,152,208,160,176,72,584,144,176) uncon = c(368,136,512,136,472,96,144,112,104,104,344,246,72,80,312,24,128,304,16,320, 560,168,120,616,24,176,16,24,32,232,32,112,56,184,40,256,160,456,48,24, 200,72,168,288,112,80,584,368,272,208,144,208,114,480,114,392,120,48,104,272, 64,112,96,64,360,136,168,176,256,112,104,272,320,8,440,224,280,8,56,216, 120,256,104,104,8,304,240,88,248,472,304,88,200,392,168,72,40,88,176,216, 152,184,400,424,88,152,184) cen = rep(630,44) t.event = c(con,uncon,cen) event1 = c(rep(1,length(con)),rep(0,length(uncon)),rep(0,length(cen))) event2 = c(rep(0,length(con)),rep(1,length(uncon)),rep(0,length(cen))) library(GFGM.copula) #res.BurrIII = MLE.GFGM.BurrIII(t.event,event1,event2,5000,3,2,0.75,eta = -71) #Alpha = res.BurrIII$Alpha[1] #Beta = res.BurrIII$Beta[1] #Gamma = res.BurrIII$Gamma[1] #res.spline = MLE.GFGM.spline(t.event,event1,event2,3,2,0.75) #g1 = res.spline$g1 #g2 = res.spline$g2 #CvM.GFGM.BurrIII(t.event,event1,event2,Alpha,Beta,Gamma,g1,g2,3,2,0.75,eta = -71)
Compute Kendall's tau and Spearman's rho with their boundaries under the generalized FGM copula.
Dependence.GFGM(p, q, theta)Dependence.GFGM(p, q, theta)
p |
Copula parameter that greater than or equal to 1. |
q |
Copula parameter that greater than 1. |
theta |
Copula parameter with restricted range. |
The admissible range of theta () is
See also Shih and Emura (2019) for details.
theta |
Dependence parameter. |
tau |
Kendall's tau. |
rho |
Spearman's rho. |
Shih J-H, Emura T (2019) Bivariate dependence measures and bivariate competing risks models under the generalized FGM copula, Statistical Papers, 60:1101-1118.
library(GFGM.copula) Dependence.GFGM(3,2,0.75)library(GFGM.copula) Dependence.GFGM(3,2,0.75)
Generate samples from the generalized FGM copula with the Burr III margins.
GFGM.BurrIII(n, p, q, theta, Alpha, Beta, Gamma)GFGM.BurrIII(n, p, q, theta, Alpha, Beta, Gamma)
n |
Sample size. |
p |
Copula parameter that greater than or equal to 1. |
q |
Copula parameter that greater than 1. |
theta |
Copula parameter with restricted range. |
Alpha |
Positive shape parameter for the Burr III margin. |
Beta |
Positive shape parameter for the Burr III margin. |
Gamma |
Common positive shape parameter for the Burr III margins. |
The admissible range of theta is given in Dependence.GFGM.
X |
|
Y |
|
Shih J-H, Emura T (2018) Likelihood-based inference for bivariate latent failure time models with competing risks udner the generalized FGM copula, Computational Statistics, 33:1293-1323.
Shih J-H, Emura T (2019) Bivariate dependence measures and bivariate competing risks models under the generalized FGM copula, Statistical Papers, 60:1101-1118.
library(GFGM.copula) GFGM.BurrIII(5,3,2,0.75,1,1,1)library(GFGM.copula) GFGM.BurrIII(5,3,2,0.75,1,1,1)
Maximum likelihood estimation for bivariate dependent competing risks data under the generalized FGM copula with the Burr III margins.
MLE.GFGM.BurrIII( t.event, event1, event2, D, p, q, theta, eta = 0, Gamma.0 = 1, epsilon.0 = 1e-05, epsilon.1 = 1e-10, epsilon.2 = 1e-300, r.1 = 1, r.2 = 1, r.3 = 1 )MLE.GFGM.BurrIII( t.event, event1, event2, D, p, q, theta, eta = 0, Gamma.0 = 1, epsilon.0 = 1e-05, epsilon.1 = 1e-10, epsilon.2 = 1e-300, r.1 = 1, r.2 = 1, r.3 = 1 )
t.event |
Vector of the observed failure times. |
event1 |
Vector of the indicators for the failure cause 1. |
event2 |
Vector of the indicators for the failure cause 2. |
D |
Positive tunning parameter in the NR algorithm. |
p |
Copula parameter that greater than or equal to 1. |
q |
Copula parameter that greater than 1 (integer). |
theta |
Copula parameter with restricted range. |
eta |
Location parameter with default value 0. |
Gamma.0 |
Initial guess for the common shape parameter gamma with default value 1. |
epsilon.0 |
Positive tunning parameter in the NR algorithm with default value 1e-5. |
epsilon.1 |
Positive tunning parameter in the NR algorithm with default value 1e-10. |
epsilon.2 |
Positive tunning parameter in the NR algorithm with default value 1e-300. |
r.1 |
Positive tunning parameter in the NR algorithm with default value 1. |
r.2 |
Positive tunning parameter in the NR algorithm with default value 1. |
r.3 |
Positive tunning parameter in the NR algorithm with default value 1. |
The copula parameter q is restricted to be a integer due to the binominal theorem.
The admissible range of theta is given in Dependence.GFGM.
n |
Sample size. |
count |
Iteration number. |
random |
Randomization number. |
Alpha |
Positive shape parameter for the Burr III margin (failure cause 1). |
Beta |
Positive shape parameter for the Burr III margin (failure cause 2). |
Gamma |
Common shape parameter for the Burr III margins. |
MeanX |
Mean lifetime due to failure cause 1. |
MeanY |
Mean lifetime due to failure cause 2. |
logL |
Log-likelihood value under the fitted model. |
Shih J-H, Emura T (2018) Likelihood-based inference for bivariate latent failure time models with competing risks udner the generalized FGM copula, Computational Statistics, 33:1293-1323.
Shih J-H, Emura T (2019) Bivariate dependence measures and bivariate competing risks models under the generalized FGM copula, Statistical Papers, 60:1101-1118.
con = c(16,224,16,80,128,168,144,176,176,568,392,576,128,56,112,160,384,600,40,416, 408,384,256,246,184,440,64,104,168,408,304,16,72,8,88,160,48,168,80,512, 208,194,136,224,32,504,40,120,320,48,256,216,168,184,144,224,488,304,40,160, 488,120,208,32,112,288,336,256,40,296,60,208,440,104,528,384,264,360,80,96, 360,232,40,112,120,32,56,280,104,168,56,72,64,40,480,152,48,56,328,192, 168,168,114,280,128,416,392,160,144,208,96,536,400,80,40,112,160,104,224,336, 616,224,40,32,192,126,392,288,248,120,328,464,448,616,168,112,448,296,328,56, 80,72,56,608,144,408,16,560,144,612,80,16,424,264,256,528,56,256,112,544, 552,72,184,240,128,40,600,96,24,184,272,152,328,480,96,296,592,400,8,280, 72,168,40,152,488,480,40,576,392,552,112,288,168,352,160,272,320,80,296,248, 184,264,96,224,592,176,256,344,360,184,152,208,160,176,72,584,144,176) uncon = c(368,136,512,136,472,96,144,112,104,104,344,246,72,80,312,24,128,304,16,320, 560,168,120,616,24,176,16,24,32,232,32,112,56,184,40,256,160,456,48,24, 200,72,168,288,112,80,584,368,272,208,144,208,114,480,114,392,120,48,104,272, 64,112,96,64,360,136,168,176,256,112,104,272,320,8,440,224,280,8,56,216, 120,256,104,104,8,304,240,88,248,472,304,88,200,392,168,72,40,88,176,216, 152,184,400,424,88,152,184) cen = rep(630,44) t.event = c(con,uncon,cen) event1 = c(rep(1,length(con)),rep(0,length(uncon)),rep(0,length(cen))) event2 = c(rep(0,length(con)),rep(1,length(uncon)),rep(0,length(cen))) library(GFGM.copula) MLE.GFGM.BurrIII(t.event,event1,event2,5000,3,2,0.75,eta = -71)con = c(16,224,16,80,128,168,144,176,176,568,392,576,128,56,112,160,384,600,40,416, 408,384,256,246,184,440,64,104,168,408,304,16,72,8,88,160,48,168,80,512, 208,194,136,224,32,504,40,120,320,48,256,216,168,184,144,224,488,304,40,160, 488,120,208,32,112,288,336,256,40,296,60,208,440,104,528,384,264,360,80,96, 360,232,40,112,120,32,56,280,104,168,56,72,64,40,480,152,48,56,328,192, 168,168,114,280,128,416,392,160,144,208,96,536,400,80,40,112,160,104,224,336, 616,224,40,32,192,126,392,288,248,120,328,464,448,616,168,112,448,296,328,56, 80,72,56,608,144,408,16,560,144,612,80,16,424,264,256,528,56,256,112,544, 552,72,184,240,128,40,600,96,24,184,272,152,328,480,96,296,592,400,8,280, 72,168,40,152,488,480,40,576,392,552,112,288,168,352,160,272,320,80,296,248, 184,264,96,224,592,176,256,344,360,184,152,208,160,176,72,584,144,176) uncon = c(368,136,512,136,472,96,144,112,104,104,344,246,72,80,312,24,128,304,16,320, 560,168,120,616,24,176,16,24,32,232,32,112,56,184,40,256,160,456,48,24, 200,72,168,288,112,80,584,368,272,208,144,208,114,480,114,392,120,48,104,272, 64,112,96,64,360,136,168,176,256,112,104,272,320,8,440,224,280,8,56,216, 120,256,104,104,8,304,240,88,248,472,304,88,200,392,168,72,40,88,176,216, 152,184,400,424,88,152,184) cen = rep(630,44) t.event = c(con,uncon,cen) event1 = c(rep(1,length(con)),rep(0,length(uncon)),rep(0,length(cen))) event2 = c(rep(0,length(con)),rep(1,length(uncon)),rep(0,length(cen))) library(GFGM.copula) MLE.GFGM.BurrIII(t.event,event1,event2,5000,3,2,0.75,eta = -71)
Maximum likelihood estimation for bivariate dependent competing risks data under the generalized FGM copula with the marginal distributions approximated by splines.
MLE.GFGM.spline(t.event, event1, event2, p, q, theta, h.plot = TRUE)MLE.GFGM.spline(t.event, event1, event2, p, q, theta, h.plot = TRUE)
t.event |
Vector of the observed failure times. |
event1 |
Vector of the indicators for the failure cause 1. |
event2 |
Vector of the indicators for the failure cause 2. |
p |
Copula parameter that greater than or equal to 1. |
q |
Copula parameter that greater than 1 (integer). |
theta |
Copula parameter with restricted range. |
h.plot |
Plot hazard functions if |
The copula parameter q is restricted to be a integer due to the binominal theorem.
The admissible range of theta is given in Dependence.GFGM.
To adapt our functions to dependent censoring models in Emura and Chen (2018), one can simply set event2 = 1-event1.
n |
Sample size. |
g1 |
Maximum likelihood estimator of the splines coefficients for the failure cause 1. |
g2 |
Maximum likelihood estimator of the splines coefficients for the failure cause 2. |
g1.var |
Covariance matrix of splines coefficients estimates for the failure cause 1. |
g2.var |
Covariance matrix of splines coefficients estimates for the failure cause 2. |
Emura T, Chen Y-H (2018) Analysis of Survival Data with Dependent Censoring, Copula-Based Approaches, JSS Research Series in Statistics, Springer, Singapore.
Shih J-H, Emura T (2018) Likelihood-based inference for bivariate latent failure time models with competing risks udner the generalized FGM copula, Computational Statistics, 33:1293-1323.
Shih J-H, Emura T (2019) Bivariate dependence measures and bivariate competing risks models under the generalized FGM copula, Statistical Papers, 60:1101-1118.
con = c(16,224,16,80,128,168,144,176,176,568,392,576,128,56,112,160,384,600,40,416, 408,384,256,246,184,440,64,104,168,408,304,16,72,8,88,160,48,168,80,512, 208,194,136,224,32,504,40,120,320,48,256,216,168,184,144,224,488,304,40,160, 488,120,208,32,112,288,336,256,40,296,60,208,440,104,528,384,264,360,80,96, 360,232,40,112,120,32,56,280,104,168,56,72,64,40,480,152,48,56,328,192, 168,168,114,280,128,416,392,160,144,208,96,536,400,80,40,112,160,104,224,336, 616,224,40,32,192,126,392,288,248,120,328,464,448,616,168,112,448,296,328,56, 80,72,56,608,144,408,16,560,144,612,80,16,424,264,256,528,56,256,112,544, 552,72,184,240,128,40,600,96,24,184,272,152,328,480,96,296,592,400,8,280, 72,168,40,152,488,480,40,576,392,552,112,288,168,352,160,272,320,80,296,248, 184,264,96,224,592,176,256,344,360,184,152,208,160,176,72,584,144,176) uncon = c(368,136,512,136,472,96,144,112,104,104,344,246,72,80,312,24,128,304,16,320, 560,168,120,616,24,176,16,24,32,232,32,112,56,184,40,256,160,456,48,24, 200,72,168,288,112,80,584,368,272,208,144,208,114,480,114,392,120,48,104,272, 64,112,96,64,360,136,168,176,256,112,104,272,320,8,440,224,280,8,56,216, 120,256,104,104,8,304,240,88,248,472,304,88,200,392,168,72,40,88,176,216, 152,184,400,424,88,152,184) cen = rep(630,44) t.event = c(con,uncon,cen) event1 = c(rep(1,length(con)),rep(0,length(uncon)),rep(0,length(cen))) event2 = c(rep(0,length(con)),rep(1,length(uncon)),rep(0,length(cen))) library(GFGM.copula) MLE.GFGM.spline(t.event,event1,event2,3,2,0.75)con = c(16,224,16,80,128,168,144,176,176,568,392,576,128,56,112,160,384,600,40,416, 408,384,256,246,184,440,64,104,168,408,304,16,72,8,88,160,48,168,80,512, 208,194,136,224,32,504,40,120,320,48,256,216,168,184,144,224,488,304,40,160, 488,120,208,32,112,288,336,256,40,296,60,208,440,104,528,384,264,360,80,96, 360,232,40,112,120,32,56,280,104,168,56,72,64,40,480,152,48,56,328,192, 168,168,114,280,128,416,392,160,144,208,96,536,400,80,40,112,160,104,224,336, 616,224,40,32,192,126,392,288,248,120,328,464,448,616,168,112,448,296,328,56, 80,72,56,608,144,408,16,560,144,612,80,16,424,264,256,528,56,256,112,544, 552,72,184,240,128,40,600,96,24,184,272,152,328,480,96,296,592,400,8,280, 72,168,40,152,488,480,40,576,392,552,112,288,168,352,160,272,320,80,296,248, 184,264,96,224,592,176,256,344,360,184,152,208,160,176,72,584,144,176) uncon = c(368,136,512,136,472,96,144,112,104,104,344,246,72,80,312,24,128,304,16,320, 560,168,120,616,24,176,16,24,32,232,32,112,56,184,40,256,160,456,48,24, 200,72,168,288,112,80,584,368,272,208,144,208,114,480,114,392,120,48,104,272, 64,112,96,64,360,136,168,176,256,112,104,272,320,8,440,224,280,8,56,216, 120,256,104,104,8,304,240,88,248,472,304,88,200,392,168,72,40,88,176,216, 152,184,400,424,88,152,184) cen = rep(630,44) t.event = c(con,uncon,cen) event1 = c(rep(1,length(con)),rep(0,length(uncon)),rep(0,length(cen))) event2 = c(rep(0,length(con)),rep(1,length(uncon)),rep(0,length(cen))) library(GFGM.copula) MLE.GFGM.spline(t.event,event1,event2,3,2,0.75)
Sub-distribution functions under the generalized FGM copula with the Burr III margins.
Sdist.GFGM.BurrIII(time, Alpha, Beta, Gamma, p, q, theta, eta = 0)Sdist.GFGM.BurrIII(time, Alpha, Beta, Gamma, p, q, theta, eta = 0)
time |
Vector of times. |
Alpha |
Positive shape parameter for the Burr III margin (failure cause 1). |
Beta |
Positive shape parameter for the Burr III margin (failure cause 2). |
Gamma |
Common positive shape parameter for the Burr III margins. |
p |
Copula parameter that greater than or equal to 1. |
q |
Copula parameter that greater than 1 (integer). |
theta |
Copula parameter with restricted range. |
eta |
Location parameter with default value 0. |
The copula parameter q is restricted to be a integer due to the binominal theorem.
The admissible range of theta is given in Dependence.GFGM.
time |
Failure times |
Sdist.1 |
Probability of an object fails due to the failure cause 1. |
Sdist.2 |
Probability of an object fails due to the failure cause 2. |
Shih J-H, Emura T (2018) Likelihood-based inference for bivariate latent failure time models with competing risks udner the generalized FGM copula, Computational Statistics, 33:1293-1323.
Shih J-H, Emura T (2019) Bivariate dependence measures and bivariate competing risks models under the generalized FGM copula, Statistical Papers, 60:1101-1118.
MLE.GFGM.BurrIII, Dependence.GFGM
library(GFGM.copula) Sdist.GFGM.BurrIII(c(1:5),1,1,1,3,2,0.75,eta = 1)library(GFGM.copula) Sdist.GFGM.BurrIII(c(1:5),1,1,1,3,2,0.75,eta = 1)
Sub-distribution functions under the generalized FGM copula with the marginal distributions approximated by splines.
Sdist.GFGM.spline(time, g1, g2, tmin, tmax, p, q, theta)Sdist.GFGM.spline(time, g1, g2, tmin, tmax, p, q, theta)
time |
Vector of times. |
g1 |
Splines coefficients for the failure cause 1. |
g2 |
Splines coefficients for the failure cause 2. |
tmin |
Lower bound of times. |
tmax |
upper bound of times. |
p |
Copula parameter that greater than or equal to 1. |
q |
Copula parameter that greater than 1 (integer). |
theta |
Copula parameter with restricted range. |
The splines coefficients g1 and g2 are usually computed by MLE.GFGM.spline.
The copula parameter q is restricted to be a integer due to the binominal theorem.
The admissible range of theta is given in Dependence.GFGM.
time |
Failure times |
Sdist.1 |
Probability of an object fails due to the failure cause 1. |
Sdist.2 |
Probability of an object fails due to the failure cause 2. |
Shih J-H, Emura T (2018) Likelihood-based inference for bivariate latent failure time models with competing risks udner the generalized FGM copula, Computational Statistics, 33:1293-1323.
Shih J-H, Emura T (2019) Bivariate dependence measures and bivariate competing risks models under the generalized FGM copula, Statistical Papers, 60:1101-1118.
MLE.GFGM.spline, Dependence.GFGM
library(GFGM.copula) Sdist.GFGM.spline(seq(1,5,1),rep(0.1,5),rep(0.1,5),1,5,3,2,0.75)library(GFGM.copula) Sdist.GFGM.spline(seq(1,5,1),rep(0.1,5),rep(0.1,5),1,5,3,2,0.75)